"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const errors_1 = require("./errors");
async function getPluginByName(name, pluginLoader) {
    const possibleNames = [
        `graphql-codegen-${name}`,
        `graphql-codegen-${name}-template`,
        `codegen-${name}`,
        `codegen-${name}-template`,
        name
    ];
    const possibleModules = possibleNames.concat(path_1.resolve(process.cwd(), name));
    for (const moduleName of possibleModules) {
        try {
            return (await pluginLoader(moduleName));
        }
        catch (err) {
            if (err.message.indexOf(`Cannot find module '${moduleName}'`) === -1) {
                throw new errors_1.DetailedError(`Unable to load template plugin matching ${name}`, `
              Unable to load template plugin matching '${name}'.
              Reason: 
                ${err.message}
            `);
            }
        }
    }
    const possibleNamesMsg = possibleNames
        .map(name => `
        - ${name}
    `.trimRight())
        .join('');
    throw new errors_1.DetailedError(`Unable to find template plugin matching ${name}`, `
        Unable to find template plugin matching '${name}'
        Install one of the following packages:
        
        ${possibleNamesMsg}
      `);
}
exports.getPluginByName = getPluginByName;
//# sourceMappingURL=plugins.js.map